{--------------------------------------------------------------------------------------------------

  ApScrollBox
  ========================
  This is an extended version of the default VCL TScrollBox. I added the OnScroll-Event so you can
  react on vertical and horizontal scrolling.

  License
  =======
  Copyright 2010, Armin Pfffle <mail@armin-pfaeffle.de>

  Released under the MIT license.
  http://www.armin-pfaeffle.de/licenses/mit

  Changelog
  =========
  17.12.2010 - v1.0.0.1
    - Added package support for Delphi 7 - XE.

  29.11.2010 - v1.0.0.0
    - Initial release.

 --------------------------------------------------------------------------------------------------}

unit ApScrollBox;

interface

uses
  Forms, Messages, Classes;

type
{--------------------------------------------------------------------------------------------------
  Direction Type.
 --------------------------------------------------------------------------------------------------}
TApAxis = (axVertical, axHorizontal);

{--------------------------------------------------------------------------------------------------
  Notification type for OnScroll-Event.
 --------------------------------------------------------------------------------------------------}
TApScrollNotification = procedure(Sender: TObject; const Axis: TApAxis) of object;

{--------------------------------------------------------------------------------------------------
  Extended version of TScrollBox.
 --------------------------------------------------------------------------------------------------}
TApScrollBox = class(TScrollBox)
private
  FOnScroll : TApScrollNotification;
  procedure WMHScroll(var Msg: TMessage); message WM_HSCROLL;
  procedure WMVScroll(var Msg: TMessage); message WM_VSCROLL;
published
  property OnScroll : TApScrollNotification read FOnScroll write FOnScroll;
end;


procedure Register;

implementation

{--------------------------------------------------------------------------------------------------
  Registers TApScrollBox.
 --------------------------------------------------------------------------------------------------}
procedure Register;
begin
  RegisterComponents('ApUtilities', [TApScrollBox]);
end;



{ TApScrollBox }

{--------------------------------------------------------------------------------------------------
  Override WMHScroll so component triggers call OnScroll-Event.
 --------------------------------------------------------------------------------------------------}
procedure TApScrollBox.WMHScroll(var Msg: TMessage);
begin
  if (Assigned(FOnScroll)) then
    FOnScroll(Self, axHorizontal);
  inherited;
end;

{--------------------------------------------------------------------------------------------------
  Override WMVScroll so component triggers call OnScroll-Event.
 --------------------------------------------------------------------------------------------------}
procedure TApScrollBox.WMVScroll(var Msg: TMessage);
begin
  if (Assigned(FOnScroll)) then
    FOnScroll(Self, axVertical);
  inherited;
end;


end.

